@@ -1,6 +1,6 @@
 from http.client import HTTPMessage
-from urllib.request import urlretrieve
-from typing import Union, Tuple
+from typing import Union
+from . import objects
 from . import exceptions
 from .utils import *
 
@@ -9,29 +9,30 @@ class compendium(object):
     Base class for pyrule compendium.
 
     Parameters:
-        * `url`: The base URL for the API.
+        * `base_url`: The base URL for the API.
             - default: "https://botw-compendium.herokuapp.com/api/v2"
             - type: string
+            - notes: Manipulate with `compendium.api.base_url`
         * `default_timeout`: Default seconds to wait for response for all API calling functions until raising `requests.exceptions.ReadTimeout`
-            - default: `None` (meaning no timeout)
+            - default: `None` (no timeout)
             - type: integer, float, tuple (for connect and read timeouts)
-            - notes: If a API calling function has a parameter `timeout`, it will overide this
+            - notes: If an API calling function has a parameter `timeout`, it will overide this
     """
 
-    def __init__(self, url: str="https://botw-compendium.herokuapp.com/api/v2", default_timeout: Union[int, float, None]=None):
-        self.url = url
+    def __init__(self, base_url: str="https://botw-compendium.herokuapp.com/api/v2", default_timeout: Union[int, float, None]=None):
+        self.api: api = api(base_url)
         self.default_timeout = default_timeout
 
-    def get_entry(self, entry: Union[str, int], timeout: Union[float, int, None]=None) -> dict:
+    def get_entry(self, entry: types.entry, timeout: types.timeout=None) -> dict:
         """
         Gets an entry from the compendium.
 
         Parameters:
             * `entry`: The entry to be retrieved.
-                - type: string, int
+                - type: str, int
             * `timeout`: Seconds to wait for response until raising `requests.exceptions.ReadTimeout`
-                - default: `self.default_timeout`
-                - type: integer, float, tuple (for connect and read timeouts)
+                - default: `compendium.default_timeout`
+                - type: int, float, tuple (for connect and read timeouts)
 
         Returns: Metadata on the entry
             - type: dict
@@ -40,13 +41,13 @@ class compendium(object):
         if not timeout:
             timeout = self.default_timeout
 
-        res: dict = api_req(f"{self.url}/entry/{entry}", timeout=timeout)
+        res: dict = self.api.request(f"/entry/{entry}", timeout)
         if res == {}:
             raise exceptions.NoEntryError(entry)
 
         return res
 
-    def get_category(self, category: str, timeout: Union[float, int, None]=None) -> Union[dict, list]:
+    def get_category(self, category: str, timeout: types.timeout=None) -> Union[dict, list]:
         """
         Gets all entries from a category in the compendium.
 
@@ -55,7 +56,7 @@ class compendium(object):
                 - type: string
                 - notes: must be in ["creatures", "equipment", "materials", "monsters", "treasure"]
             * `timeout`: Seconds to wait for response until raising `requests.exceptions.ReadTimeout`
-                - default: `self.default_timeout`
+                - default: `compendium.default_timeout`
                 - type: integer, float, tuple (for connect and read timeouts)
 
         Returns: All entries in the category. 
@@ -69,15 +70,15 @@ class compendium(object):
         if category not in ["creatures", "equipment", "materials", "monsters", "treasure"]:
             raise exceptions.NoCategoryError(category)
 
-        return api_req(f"{self.url}/category/{category}", timeout=timeout)
+        return self.api.request(f"/category/{category}", timeout)
 
-    def get_all(self, timeout: Union[float, int, None]=None) -> dict:
+    def get_all(self, timeout: types.timeout=None) -> Union[dict, list]:
         """
         Get all entries from the compendium.
 
         Parameters:
             * `timeout`: Seconds to wait for response until raising `requests.exceptions.ReadTimeout`
-                - default: `self.default_timeout`
+                - default: `compendium.default_timeout`
                 - type: integer, float, tuple (for connect and read timeouts)
 
         Returns: all items in the compendium with their metadata nested in categories.
@@ -87,32 +88,18 @@ class compendium(object):
         if not timeout:
             timeout = self.default_timeout
 
-        return api_req(self.url, timeout=timeout)
+        return api_req(self.api.base_url, timeout)
 
-    def download_entry_image(self, entry: Union[int, str], output_file: Union[str, None]=None, get_entry_timeout: Union[int, float, None]=None) -> Tuple[str, HTTPMessage]:
+    def get_image(self, entry: types.entry) -> objects.entry_image:
         """
-        Download the image of a compendium entry.
+        Retrieves the image of a compendium entry.
 
         Parameters:
-            * `entry`: The ID or name of the entry of the image to be downloaded.
+            * `entry`: The ID or name of the entry.
                 - type: str, int
-            * `output_file`: The output file's path.
-                - default: entry's name with a ".png" extension with spaces replaced by underscores
-                - type: str
-            * `get_entry_timeout`: Seconds to wait for response until raising `requests.exceptions.ReadTimeout`.
-                - default: `self.default_timeout`
-                - type: int, float, tuple (for connect and read timeouts)
 
-        Returns: path to the newly created image and the resulting HTTPMessage object.
-            - type: tuple
+        Returns: Entry image object
+            - type: `objects.entry_image`
         """
 
-        if not get_entry_timeout:
-            get_entry_timeout = self.default_timeout
-
-        entry_data: dict = self.get_entry(entry, timeout=get_entry_timeout)
-
-        if not output_file:
-            output_file = f"{entry_data['name'].replace(' ', '_')}.png"
-
-        return urlretrieve(entry_data["image"], output_file)
\ No newline at end of file
+        return objects.entry_image(self.get_entry(entry), self.api)
\ No newline at end of file
